OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Apakah Anda ingin menambahkan pembagian remote {name} dari {owner}@{remote}?",
    "Remote share" : "Berbagi remote",
    "Remote share password" : "Kata sandi berbagi jarak jauh",
    "Cancel" : "Batalkan",
    "Add remote share" : "Tambah berbagi remote",
    "Invalid Federated Cloud ID" : "Federated Cloud ID tidak sah",
    "Server to server sharing is not enabled on this server" : "Berbagi server ke server tidak diaktifkan pada server ini",
    "Couldn't establish a federated share." : "Tidak dapat mendirikan pembagian terfederasi",
    "Couldn't establish a federated share, maybe the password was wrong." : "Tidak dapat mendirikan pembagian terfederasi, mungkin kata sandi salah.",
    "Not allowed to create a federated share with the same user" : "Tidak diizinkan membuat pembagian terfederasi dengan pengguna yang sama",
    "File is already shared with %s" : "Berkas sudah dibagikan dengan %s",
    "Could not find share" : "Tidak dapat mencari pembagian",
    "Federated sharing" : "Pembagian terfederasi",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Anda menerima {share} sebagai berbagi jauh dari {user} (atas nama {behalf})",
    "You received {share} as a remote share from {user}" : "Anda menerima {share} sebagai berbagi jauh dari {user}",
    "Accept" : "Terima",
    "Decline" : "Tolak",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Dibagikan pada saya melalui #Nextcloud Federated Cloud ID saya, lihat %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Dibagikan pada saya melalui #Nextcloud Federated Cloud ID saya",
    "Sharing" : "Berbagi",
    "Allow users on this server to receive shares from other servers" : "Izinkan para pengguna di server ini untuk menerima berbagi ke server lainnya.",
    "Search global and public address book for users" : "Cari alamat buku global dan alamat publik untuk pengguna",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Federated Cloud ID Anda:",
    "Twitter" : "Twitter",
    "Add to your website" : "Tambahkan pada situs web Anda",
    "Share with me via Nextcloud" : "Dibagikan pada saya via Nextcloud",
    "HTML Code:" : "Kode HTML:",
    "Copy" : "Salin",
    "Copied!" : "Tersalin!",
    "Not supported!" : "Tidak didukung!",
    "Press ⌘-C to copy." : "Tekan ⌘-C untuk menyalin.",
    "Press Ctrl-C to copy." : "Tekan Ctrl-C untuk menyalin.",
    "Open documentation" : "Buka dokumentasi"
},
"nplurals=1; plural=0;");
